@@ -28,6 +28,10 @@ DEFAULT_NETBOX_CONFIG = {
 class CacheFile:
     path: Path
 
+    def __post_init__(self):
+        if not self.path.exists():
+            self.path.parent.mkdir(parents=True, exist_ok=True)
+
     def search_host(self, partial_host: str) -> Optional[str]:
         if self.path.exists():
             all_hosts = self.path.read_text().splitlines()
@@ -135,6 +139,12 @@ class NetboxResolver(Resolver):
 
         return full_hostname
 
+    def __repr__(self) -> str:
+        return self.__str__()
+
+    def __str__(self) -> str:
+        return f"NetboxResolver(api_token=*******, netbox_url='{self.netbox_url}', cache_file='{self.cachefile}')"
+
 
 @dataclass
 class OpenstackBrowserResolrver(Resolver):
@@ -255,7 +265,14 @@ def try_ssh(hostname: str, cachefile: Optional[CacheFile], user: str = None) ->
     )
 
 
-@click.command(name="wm-ssh", help="Wikimedia ssh wrapper that expands hostnames")
+@click.command(
+    name="wm-ssh",
+    help="Wikimedia ssh wrapper that expands hostnames",
+    epilog=(
+        "Note that any options to ssh have to be passed after the hostname (ex. wm-ssh dummy-host -D 127.0.0.1:8080)"
+    ),
+    context_settings={"ignore_unknown_options": True},
+)
 @click.option("-v", "--verbose", help="Show extra verbose output", is_flag=True)
 @click.option("--print-config", help="Show the loaded configuration", is_flag=True)
 @click.option(
@@ -269,7 +286,7 @@ def try_ssh(hostname: str, cachefile: Optional[CacheFile], user: str = None) ->
 )
 @click.option("--flush-caches", help="Clean the caches, this removes any cached hosts.", is_flag=True, default=False)
 @click.argument("hostname", required=False, default=None)
-@click.argument("args", nargs=-1, type=click.UNPROCESSED)
+@click.argument("sshargs", nargs=-1, type=click.UNPROCESSED)
 def wm_ssh(
     verbose: bool,
     print_config: bool,
@@ -277,7 +294,7 @@ def wm_ssh(
     config_file: Path,
     no_caches: bool,
     flush_caches: bool,
-    args: List[str],
+    sshargs: List[str],
 ) -> int:
     if verbose:
         logging.basicConfig(level=logging.DEBUG)
@@ -289,10 +306,6 @@ def wm_ssh(
         print(json.dumps(config, indent=4))
         return 0
 
-    if not hostname:
-        print("Error: Missing argument 'HOSTNAME'")
-        return 1
-
     known_hosts_cachefile = CacheFile(path=DEFAULT_CACHE_PATH / "known_hosts.txt")
     netbox_cachefile = CacheFile(path=DEFAULT_CACHE_PATH / "netbox.txt")
     openstack_cachefile = CacheFile(path=DEFAULT_CACHE_PATH / "openstackbrowser.txt")
@@ -302,12 +315,18 @@ def wm_ssh(
         netbox_cachefile.replace_content("")
         openstack_cachefile.replace_content("")
         direct_cachefile.replace_content("")
+        if not hostname:
+            return 0
 
     if no_caches:
         netbox_cachefile = None
         openstack_cachefile = None
         direct_cachefile = None
 
+    if not hostname:
+        print("Error: Missing argument 'HOSTNAME'")
+        return 1
+
     resolvers = [
         KnownHostsResolver(
             known_hosts_url=config["known_hosts_url"],
@@ -338,26 +357,30 @@ def wm_ssh(
         user = None
 
     full_hostname = try_ssh(hostname, cachefile=direct_cachefile, user=user)
-    LOGGER.debug("Using resolvers: %s", resolvers)
-    for resolver in resolvers:
-        LOGGER.debug("Trying resolver %s", resolver)
-        try:
-            full_hostname = resolver.get_host(hostname=hostname)
-            if full_hostname:
-                break
-        except Exception as error:
-            LOGGER.warning(f"Got error when trying to fetch host from {resolver}: {error}")
+    if full_hostname:
+        LOGGER.debug("I was able to ssh directly, just continuing.")
+    else:
+        LOGGER.debug("Direct ssh failed, trying to resolve.")
+        LOGGER.debug("Using resolvers: %s", resolvers)
+        for resolver in resolvers:
+            LOGGER.debug("Trying resolver %s", resolver)
+            try:
+                full_hostname = resolver.get_host(hostname=hostname)
+                if full_hostname:
+                    break
+            except Exception as error:
+                LOGGER.warning(f"Got error when trying to fetch host from {resolver}: {error}")
 
-    if not full_hostname:
-        LOGGER.error("Unable to find a hostname for '%s'", hostname)
-        sys.exit(1)
+        if not full_hostname:
+            LOGGER.error("Unable to find a hostname for '%s'", hostname)
+            sys.exit(1)
 
     LOGGER.info("Found full hostname %s", full_hostname)
     if user:
         full_hostname = f"{user}@{full_hostname}"
 
     LOGGER.debug("Waiting for ssh to finish...")
-    _do_ssh(full_hostname=full_hostname, args=args)
+    _do_ssh(full_hostname=full_hostname, args=sshargs)
     LOGGER.debug("Done")
     return 0
 
